@@ -1,5 +1,5 @@
-from dm.command import DomainObjectCreate
-from dm.command import DomainObjectRead
+from dm.command.base import DomainObjectCreate
+from dm.command.base import DomainObjectRead
 
 class CaptchaCreate(DomainObjectCreate):
     "Command to create a captcha."
