@@ -1,7 +1,12 @@
+import os
 from dm.command.base import Command
 from dm.command.state import *
 from dm.command.accesscontrol import GrantStandardSystemAccess
 from dm.command.person import *
+import shutil
+import pkg_resources
+from dm.dictionarywords import TEMPLATES_RESOURCE_PATH, MEDIA_RESOURCE_PATH
+from dm.dictionarywords import SYSTEM_NAME, DJANGO_TEMPLATES_DIR, MEDIA_PATH
 
 class InitialiseDomainModelBase(Command):
 
@@ -169,3 +174,51 @@ class InitialiseDomainModel(InitialiseDomainModelBase):
         purgePerson('anna')
         purgePerson('bolskonski')
 
+class InitialiseFilesystem(object):
+
+    packageName = None
+
+    def __init__(self, dictionary=None, verbose=False):
+        self.dictionary = dictionary
+        self.templatesResourcePath = self.dictionary[TEMPLATES_RESOURCE_PATH]
+        self.mediaResourcePath = self.dictionary[MEDIA_RESOURCE_PATH]
+        self.packageName = self.dictionary[SYSTEM_NAME]
+        self.verbose = verbose
+
+    def execute(self):
+        self.installTemplates()
+        self.installMedia()
+
+    def installTemplates(self):
+        installPath = self.dictionary[DJANGO_TEMPLATES_DIR]
+        self.installFiles('templates', self.templatesResourcePath, installPath)
+
+    def installMedia(self):
+        installPath = self.dictionary[MEDIA_PATH]
+        self.installFiles('media', self.mediaResourcePath, installPath)
+
+    def installFiles(self, purpose, resourcePath, installPath):
+        installPath = os.path.normpath(installPath)
+        try:
+            fullResourcePath = pkg_resources.resource_filename(
+                pkg_resources.Requirement.parse(self.packageName),
+                '%s/%s' % (self.packageName, resourcePath )
+            )
+        except Exception, inst:
+            msg = "Couldn't make full '%s' package resource path for '%s': %s" % (
+                self.packageName,
+                resourcePath,
+                repr(inst)
+            )
+            raise Exception, msg
+        if os.path.exists(installPath):
+            print "Skipping %s: The folder already exists: %s" % (purpose, installPath)
+        else:
+            self.assertFolder(os.path.dirname(installPath))
+            shutil.copytree(fullResourcePath, installPath)
+
+    def assertFolder(self, folderPath):
+        if not os.path.exists(folderPath):
+            os.makedirs(folderPath)
+
+
