@@ -24,11 +24,10 @@ support for other Object Relational Mappers (such as SQLAlchemy and Elixir).
 This module is a Model Persistence Mapper (MPM), and although there are 
 similar aspects to both MPMs and ORMs, this module does not build or execute
 SQL statements and so cannot be classified as an ORM. Instead, this module
-depends on an ORM to move values from the persistence model to the DBRMS.
+depends on an ORM to move values from the persistence model to the RDBMS.
 
 """
 
-# Todo: Expand for all database systems (not just 'postgres').
 from dm.exceptions import *
 
 import sqlobject
@@ -68,6 +67,7 @@ import weakref
 
 debug = RequiredFeature('Debug')
 logger = RequiredFeature('Logger')
+dictionary = RequiredFeature('SystemDictionary')
 
 moddebug = False
 
@@ -77,13 +77,13 @@ class ConnectionFacade(object):
     dictionary = RequiredFeature('SystemDictionary')
 
     def __init__(self):
-        dbType = self.dictionary[DB_TYPE]
-        dbUser = self.dictionary[DB_USER]
-        dbPass = self.dictionary[DB_PASS]
-        dbHost = self.dictionary[DB_HOST]
-        dbName = self.dictionary[DB_NAME]
-        if self.dictionary.has_key(DB_URI):
-            uri = self.dictionary[DB_URI]
+        dbType = dictionary[DB_TYPE]
+        dbUser = dictionary[DB_USER]
+        dbPass = dictionary[DB_PASS]
+        dbHost = dictionary[DB_HOST]
+        dbName = dictionary[DB_NAME]
+        if dictionary.get(DB_URI, None):
+            uri = dictionary[DB_URI]
         elif dbType == 'sqlite':
             uri = "sqlite://%s" % dbName
         else:
@@ -366,7 +366,7 @@ class ReservedNames(object):
     reservedNames = None
     dictionary = RequiredFeature('SystemDictionary')
 
-    sqlKeywords = {
+    sqlKeywordLists = {
         'common': [
             'ABSOLUTE', 'ADD', 'ADMIN', 'AFTER',
             'AND', 'ANY', 'ARE', 'ARRAY', 'AS',
@@ -440,12 +440,12 @@ class ReservedNames(object):
 
     def getReservedNames(self):
         if self.reservedNames == None:
-            self.reservedNames = self.sqlKeywords['common']
-            dbType = self.dictionary[DB_TYPE]
-            if dbType in self.sqlKeywords:
-                self.reservedNames += self.sqlKeywords[dbType]
+            self.reservedNames = self.sqlKeywordLists['common']
+            dbType = dictionary[DB_TYPE]
+            if dbType in self.sqlKeywordLists:
+                self.reservedNames += self.sqlKeywordLists[dbType]
             else:
-                self.reservedNames += self.sqlKeywords['default']
+                self.reservedNames += self.sqlKeywordLists['default']
         return self.reservedNames
 
     getReservedNames = classmethod(getReservedNames)
@@ -555,6 +555,7 @@ class MetaMapper(MetaBase):
 
     def getSQLObjectAttributes(self):
         mapperAttributes = {}
+        dbType = dictionary[DB_TYPE]
         for a in self.attributes:
             if a.dom.isTemporal:
                 # We don't persist temporal attributes on the parent.
@@ -571,9 +572,11 @@ class MetaMapper(MetaBase):
                 mapperAttributes[setMethodName] = setMethod
                 mapperAttributes[getMethodName] = getMethod
             if a.dom.isIndexed:
-                indexName = "%sIndex" % a.dbName
-                index = DatabaseIndex(mapperClassAttribute)
-                mapperAttributes[indexName] = index
+                # Indexes are tripping up MySQL.
+                if dbType not in ['mysql']:
+                    indexName = "%sIndex" % a.dbName
+                    index = DatabaseIndex(mapperClassAttribute)
+                    mapperAttributes[indexName] = index
         return mapperAttributes
 
     def getSQLObjectIndexes(self):
@@ -714,7 +717,6 @@ class Mapper(SQLObject):
 
     domainObject = None
 
-
     def __init__(self, **kwds):
         self.coerceKwds(kwds)
         super(Mapper, self).__init__(**kwds)
@@ -849,7 +851,7 @@ class Mapper(SQLObject):
                 logger.info(msg)
             if domName == 'parent' and metaAttr.isDomainObjectRef:
                 # Continue if it's already loaded....
-                if self.parent and self.parent.domainObject():
+                if self.parent and self.parent.domainObject and self.parent.domainObject():
                     mapperValue = self.parent.domainObject()
                     self.domainObject().parent = mapperValue
                     continue
@@ -884,6 +886,8 @@ class Mapper(SQLObject):
                 if (mappedValue != None) and (mappedValue != ''):
                     # Coerse to DateTime.
                     # todo: stabilise SQLObject's date-time choice
+                    # That strange behaviour seems to be a symptom of having
+                    # different mx.DateTime packages installed and available.
                     mappedValue = mx.DateTime.DateTime(
                         mappedValue.year,
                         mappedValue.month,
@@ -1088,7 +1092,9 @@ class Mapper(SQLObject):
     selectByKeywords = classmethod(selectByKeywords)
 
     def startsWith(self, value, attributeName, **kwds):
-        sqlSafeValue = sqlrepr(value, 'postgres')[1:-1] # drop quotes
+        # todo: expand for all database systems
+        dbType = dictionary[DB_TYPE]
+        sqlSafeValue = sqlrepr(value, dbType)[1:-1] # drop quotes
         dbName = self.getAttributeDbName(attributeName)
         sqlSafeName = self.makeSqlName(dbName)
         sqlLike = "UPPER(%s) LIKE UPPER('%s')" % (sqlSafeName, sqlSafeValue+'%')
@@ -1100,7 +1106,7 @@ class Mapper(SQLObject):
                 if self.meta.attributeDbNames[name].isDomainObjectRef:
                     name += '_id'
             # todo: expand for all database systems
-            sqlSafeValue = sqlrepr(value, 'postgres')
+            sqlSafeValue = sqlrepr(value, dbType)
             sqlSafeName = self.makeSqlName(name)
             if sqlSafeValue.upper() == 'NULL':
                 sqlEquals = "%s IS %s" % (sqlSafeName, sqlSafeValue)
@@ -1119,7 +1125,8 @@ class Mapper(SQLObject):
             dbNames.append(dbName)
         sqlLikeList = []
         # todo: expand for all database systems
-        sqlSafeQuery = sqlrepr(userQuery, 'postgres')
+        dbType = dictionary[DB_TYPE]
+        sqlSafeQuery = sqlrepr(userQuery, dbType)
         sqlSafeQuery = sqlSafeQuery[1:-1] # Drop quotes (added later).
         if spaceSplit:
             sqlSafeTerms = sqlSafeQuery.split(' ')
@@ -1145,7 +1152,8 @@ class Mapper(SQLObject):
             if sqoVer in ['0.10', '0.11', '0.12']:
                 if self.meta.attributeDbNames[name].isDomainObjectRef:
                     name += '_id'
-            sqlSafeValue = sqlrepr(value, 'postgres')
+            # todo: expand for all database systems
+            sqlSafeValue = sqlrepr(value, dbType)
             sqlSafeName = self.makeSqlName(name)
             if sqlSafeValue.upper() == 'NULL':
                 sqlEquals = "%s IS %s" % (sqlSafeName, sqlSafeValue)
@@ -1164,6 +1172,7 @@ class Mapper(SQLObject):
     def selectByKeywordsWithId(self, **kwds):
         self.coerceKwds(kwds)
         sqlEqualsList = []
+        dbType = dictionary[DB_TYPE]
         for name in kwds:
             value = kwds[name]
             if sqoVer in ['0.10', '0.11', '0.12'] and name != 'id':
@@ -1177,7 +1186,7 @@ class Mapper(SQLObject):
                     msg = "Couldn't cast %s id to int: '%s'" % (className, value)
                     raise KeyError, msg  # Django templates to carry on.
             # todo: expand for all database systems
-            sqlSafeValue = sqlrepr(value, 'postgres')
+            sqlSafeValue = sqlrepr(value, dbType)
             sqlSafeName = self.makeSqlName(name)
             if sqlSafeValue.upper() == 'NULL':
                 sqlEquals = "%s IS %s" % (sqlSafeName, sqlSafeValue)
@@ -1193,10 +1202,11 @@ class Mapper(SQLObject):
     def selectByKeywordsWithTimeInterval(self, **kwds):
         self.coerceKwds(kwds)
         sqlEqualsList = []
+        dbType = dictionary[DB_TYPE]
         for name in kwds:
             value = kwds[name]
             # todo: expand for all database systems
-            sqlSafeValue = sqlrepr(value, 'postgres')
+            sqlSafeValue = sqlrepr(value, dbType)
             if name == '__startsBefore__':
                 sqlSafeName = self.makeSqlName('starts')
                 sqlEquals = "%s < %s" % (
