@@ -82,11 +82,14 @@ class SystemDictionary(dict):
         self[SKIP_EMAIL_SENDING]  = ''
         self[EMAIL_NOTIFY_CHANGES]= ''
         self[IMAGES_DIR_PATH]     = ''
-        self[DB_TYPE]             = 'postgres'
+        # Potential values: 'mysql', 'postgres', 'sqlite', 'firebird', 'sybase', 'maxdb', 'mssql'.
+        self[DB_TYPE]             = 'postgres' 
         self[DB_HOST]             = 'localhost'
         self[DB_NAME]             = self[SYSTEM_NAME]
         self[DB_USER]             = self[DB_NAME]
         self[DB_PASS]             = ''
+        self[DB_SUPER_USER]       = ''
+        self[DB_SUPER_PASS]       = ''
         self[DB_CREATE_COMMAND]   = ''  # Default depends on DB_TYPE.
         self[DB_DELETE_COMMAND]   = ''  # Default depends on DB_TYPE.
         self[DB_MIGRATION_IN_PROGRESS] = ''
@@ -98,6 +101,8 @@ class SystemDictionary(dict):
         self[MEMOS_LIMIT]         = '3000'
         self[MEMOS_EXPIRE]        = '30'
         self[MEMOS_ENABLED]       = ''
+        self[TEMPLATES_RESOURCE_PATH] = 'django/templates'
+        self[MEDIA_RESOURCE_PATH] = 'django/media'
 
     def makeConfigFilePath(self):
         self.configFilePath = self.environment.getConfigFilePath().strip()
@@ -145,15 +150,20 @@ class SystemDictionary(dict):
             self[MEDIA_HOST] = self[DOMAIN_NAME]
         if not self[MEDIA_PORT]:
             self[MEDIA_PORT] = self[HTTP_PORT]
+        # Database super user.
+        if not self[DB_SUPER_USER]:
+            self[DB_SUPER_USER] = self[DB_USER]
+        if not self[DB_SUPER_PASS]:
+            self[DB_SUPER_PASS] = self[DB_PASS]
         # Database create and delete commands.
         dbCmds = {
           'postgres': {
-            'create': "createdb -h %(host)s -U %(user)s %(name)s",
-            'delete': "dropdb -h %(host)s -U %(user)s %(name)s",
+            'create': "createdb -h %(host)s -U %(super_user)s %(name)s",
+            'delete': "dropdb -h %(host)s -U %(super_user)s %(name)s",
           },
           'mysql': {
-            'create': "mysqladmin -h %(host)s -u %(user)s -p create %(name)s",
-            'delete': "mysqladmin -h %(host)s -u %(user)s -p --force drop %(name)s",
+            'create': "mysqladmin -h'%(host)s' -u'%(super_user)s' -p'%(super_pass)s' create %(name)s",
+            'delete': "mysqladmin -h'%(host)s' -u'%(super_user)s' -p'%(super_pass)s' --force drop %(name)s",
           },
           'sqlite': {
             'create': "touch %(name)s",
@@ -161,13 +171,19 @@ class SystemDictionary(dict):
           },
         }
         dbVars = {
-          'host': self[DB_HOST],
+          'name': self[DB_NAME],
           'user': self[DB_USER],
-          'name': self[DB_NAME]
+          'pass': self[DB_PASS],
+          'host': self[DB_HOST],
+          'super_user': self[DB_SUPER_USER],
+          'super_pass': self[DB_SUPER_PASS],
         }
         if not self[DB_CREATE_COMMAND]:
             if self[DB_TYPE] in dbCmds:
-                cmd = dbCmds[self[DB_TYPE]]['create'] % dbVars
+                try:
+                    cmd = dbCmds[self[DB_TYPE]]['create'] % dbVars
+                except:
+                    msg = "Couldn't generate %s database create command. Commands: %s Vars: %s" % (self[DB_TYPE], dbCmds, dbVars)
                 self[DB_CREATE_COMMAND] = cmd
             else:
                 msg = "Inferring database create command for database type"
@@ -177,7 +193,10 @@ class SystemDictionary(dict):
                 raise Exception, msg
         if not self[DB_DELETE_COMMAND]:
             if self[DB_TYPE] in dbCmds:
-                cmd = dbCmds[self[DB_TYPE]]['delete'] % dbVars
+                try:
+                    cmd = dbCmds[self[DB_TYPE]]['delete'] % dbVars
+                except:
+                    msg = "Couldn't generate %s database delete command. Commands: %s Vars: %s" % (self[DB_TYPE], dbCmds, dbVars)
                 self[DB_DELETE_COMMAND] = cmd
             else:
                 msg = "Inferring database delete command for database type"
