@@ -15,6 +15,8 @@ DB_HOST = 'db.host'
 DB_NAME = 'db.name'
 DB_USER = 'db.user'
 DB_PASS = 'db.pass'
+DB_SUPER_USER = 'db.super_user'
+DB_SUPER_PASS = 'db.super_pass'
 OLD_DB_PASS = 'db.password'
 DB_DELETE_COMMAND = 'db.delete_command'
 DB_CREATE_COMMAND = 'db.create_command'
@@ -62,3 +64,5 @@ SYSTEM_UP_SINCE = 'system_up_since'
 MEMOS_LIMIT = 'memos.limit'
 MEMOS_EXPIRE = 'memos.expire'
 MEMOS_ENABLED = 'memos.enabled'
+TEMPLATES_RESOURCE_PATH = 'resources.templates_dir'
+MEDIA_RESOURCE_PATH = 'resources.media_dir'
