@@ -7,10 +7,11 @@ from dm.exceptions import *
 import dm.times
 from dm.util.datastructure import MultiValueDict
 from dm.dictionarywords import DB_MIGRATION_IN_PROGRESS
+import traceback
 
 debug = RequiredFeature('Debug')
 moddebug = False
-    
+ 
 class DomainBase(object):
     """
     'Layer Supertype (475)'  [Fowler, 2003]
@@ -25,7 +26,6 @@ class DomainBase(object):
         return getattr(self, pathPart)
 
 
-# Todo: Rename as AbstractRegister - this class is NOT a list. :-)
 class AbstractRegister(DomainBase): 
     """
     Supertype for domain model registers.
@@ -76,19 +76,17 @@ class AbstractRegister(DomainBase):
         "Returns keyed object."
         if self.isCached:
             if key in self.cache:
-                if moddebug and debug:
-                    message = "Cache hit for key: '%s'" % key
-                    self.log.debug(message)
+                if moddebug:
+                    msg = "Model: Cache hit for key: '%s'" % key
+                    self.log.info(msg)
                 return self.readCache(key)
             else:
-                if moddebug and debug:
-                    message = "Cache miss for key: '%s'" % key
-                    self.log.debug(message)
-        if moddebug and debug:
-            message = "Retrieving from %s record for key: '%s'" % (self, key)
-            if message == 'WeekEarmarkTemplate':
-                raise Exception(message)
-            self.log.debug(message)
+                if moddebug:
+                    msg = "Model: Cache miss for key: '%s'" % key
+                    self.log.info(msg)
+        if moddebug:
+            msg = "Model: Retrieving from %s record for key: '%s'" % (self, key)
+            self.log.info(msg)
         return self.retrieveItem(key)
 
     def retrieveItem(self, *args, **kwds):
@@ -173,6 +171,8 @@ class DomainObjectRegister(AbstractRegister):
                 message = "findDomainObject() returned: %s" % unicode(item)
                 raise StandardError(message)
         except StandardError, inst:
+            #trace = traceback.format_exc()
+            #self.log.error("Model: Error calling findDomainObject() method: %s" % trace)
             msg = "No %s called '%s' found: %s" \
                 % (self.typeName, key, inst)
             raise KforgeRegistryKeyError(msg)
@@ -203,8 +203,12 @@ class DomainObjectRegister(AbstractRegister):
  
     def __delitem__(self, key):
         "Supports: del registry[key]"
+        self.pop(key)
+ 
+    def pop(self, key):
         item = self[key]
         item.delete()
+        return item
         
     def count(self, **kwds):
         "Returns count of matching records."
@@ -277,10 +281,12 @@ class DomainObjectRegister(AbstractRegister):
         "Finds existing object."
         kwds = dict()
         keyName = self.getKeyName()
-        if keyName: 
+        if keyName:
             kwds[keyName] = key
+            self.coerceKwds(kwds)
             record = self.findRecord(**kwds)
-            return record.getDomainObject()
+            loadedList = set(kwds.values())
+            return record.getDomainObject(loadedList=loadedList)
         else:
             raise Exception, "No keyName set on %s" % self
 
@@ -308,6 +314,11 @@ class DomainObjectRegister(AbstractRegister):
     
     def findDomainObjects(self, __loadedList__=None, **kwds):
         objectList = []
+        if __loadedList__ == None:
+            __loadedList__ = set()
+        self.coerceKwds(kwds)
+        for value in kwds.values():
+            __loadedList__.add(value)
         for record in self.findRecords(**kwds):
             domainObject = record.getDomainObject(__loadedList__)
             objectList.append(domainObject)
@@ -411,7 +422,10 @@ class DomainObjectRegister(AbstractRegister):
     
     def decacheKey(self, key):
         "Removes key from in-memory cache."
-        del self.cache[key]
+        try:
+            del self.cache[key]
+        except:
+            pass
     
     def getRegisterKey(self, domainObject):
         "Returns key for domain object in register."
@@ -454,22 +468,22 @@ class DomainObjectRegister(AbstractRegister):
         objectList = [domainObject for domainObject in self]
         return objectList
     
-    def getReverseSortedList(self):
-        objectList = self.getSortedList()
-        objectList.reverse()
-        return objectList
-
     def getSortedList(self):
         objectList = self.getObjectList()
         #self.sortDomainObjects(objectList)
         return objectList
 
+    def getReverseSortedList(self):
+        objectList = self.getSortedList()
+        objectList.reverse()
+        return objectList
+
     def sortDomainObjects(self, domainObjects):
         if debug:
             count = len(domainObjects)
             if count:
                 className = domainObjects[0].__class__.__name__
-                msg = "Sorting %s %s domain objects." % (count, className)
+                msg = "Model: Sorting %s %s domain objects." % (count, className)
                 self.log.debug(msg)
         domainObjects.sort(self.cmpDomainObjects)
 
@@ -539,6 +553,7 @@ class DomainObject(DomainBase):
 
     registerKeyName = 'id'
     registerClass = Register
+    principalRegister = None
     meta = None
     metaClass = MetaDomainObject
     paths = RequiredFeature('FileSystem') 
@@ -585,16 +600,16 @@ class DomainObject(DomainBase):
     def __repr__(self):
         className = self.__class__.__name__
         reprAttrs = self.reprAttrs()
-        return "<%s %s>" % (className, reprAttrs)
+        return "<%s%s>" % (className, reprAttrs)
 
     def reprAttrs(self):
-        reprAttrs = ' id=%d' % self.id
+        reprAttrs = " id='%d'" % self.id
         if self.meta:
             for attr in self.meta.attributes:
                 if attr.isValueRef and not attr.isBLOB:
-                    reprAttrs += ' %s' % attr.createObjectRepr(self)
+                    reprAttrs += ' ' + attr.createObjectRepr(self)
                 elif attr.isDomainObjectRef:
-                    reprAttrs += ' %s' % attr.createObjectRepr(self)
+                    reprAttrs += ' ' + attr.createObjectRepr(self)
         return reprAttrs
 
     def getSortOnValue(self):
@@ -644,6 +659,13 @@ class DomainObject(DomainBase):
                 dictValues[attr.name] = attr.createValueRepr(self)
         return dictValues
 
+    def asDictLabels(self):
+        labels = {} 
+        if self.meta:
+            for attr in self.meta.attributes:
+                labels[attr.name] = attr.createLabelRepr(self)
+        return labels
+
     def present(self):
         return self.asDictLabels()
 
@@ -663,13 +685,6 @@ class DomainObject(DomainBase):
                     requestParams[attrName] = ''
         return requestParams
 
-    def asDictLabels(self):
-        labels = {} 
-        if self.meta:
-            for attr in self.meta.attributes:
-                labels[attr.name] = attr.createLabelRepr(self)
-        return labels
-
     def assertIsClassRegistered(self):
         className = self.__class__.__name__
         if not self.isClassRegistered(self.__class__):
@@ -747,6 +762,8 @@ class DomainObject(DomainBase):
 
     def purgeAggregateList(self, attrName):
         aggregateRegister = getattr(self, attrName)
+        if aggregateRegister.isStateful:
+            aggregateRegister = aggregateRegister.getDeleted()
         for aggregateObject in aggregateRegister:
             aggregateObject.purge()
 
@@ -760,53 +777,101 @@ class DomainObject(DomainBase):
 
     def raiseCreate(self):
         "Raises onCreate event."
-        self.onCreate()
-        message = "Created %s: '%s'" % (
+        message = "Model: Created %s '%s': %s" % (
             self.__class__.__name__,
-            self.getRegisterKeyValue()
+            self.getRegisterKeyValue(),
+            repr(self)
         )
         self.log.info(message)
+        try:
+            self.onCreate()
+        except Exception, inst:
+            trace = traceback.format_exc()
+            self.log.error("Model: Error raising create event: %s" % trace)
+            try:
+                self.uncreate()
+            except Exception, inst:
+                trace = traceback.format_exc()
+                self.log.error("Model: Couldn't undo create: %s" % trace)
+            raise
+
+    def uncreate(self):
+        self.delete()
+        # Todo: Move this down to Stateful class.
+        if hasattr(self, 'purge'):
+            self.purge()
 
     def raiseUpdate(self):
         "Raises onUpdate event."
-        self.onUpdate()
         if debug:
-            message = u"Updated %s: '%s'" % (
+            message = "Model: Updated %s: '%s'" % (
                 self.__class__.__name__,
                 self
             )
             self.log.debug(message)
+        try:
+            self.onUpdate()
+        except Exception, inst:
+            trace = traceback.format_exc()
+            self.log.error("Model: Error raising update event: %s" % trace)
+            raise
 
     def raiseDelete(self):
         "Raises onDelete event."
-        self.onDelete()
-        message = "Deleted %s: '%s'" % (
+        message = "Model: Deleted %s: '%s'" % (
             self.__class__.__name__,
             self.getRegisterKeyValue()
         )
         self.log.info(message)
+        try:
+            self.onDelete()
+        except Exception, inst:
+            trace = traceback.format_exc()
+            self.log.error("Model: Error raising delete event: %s" % trace)
+        # Don't re-raise event, because it trips up undoing create.
 
     def raiseApprove(self):
         "Raises onApprove event."
-        self.onApprove()
-        message = "Approved %s: '%s'" % (
+        message = "Model: Approved %s: '%s'" % (
             self.__class__.__name__,
             self.getRegisterKeyValue()
         )
         self.log.info(message)
+        try:
+            self.onApprove()
+        except Exception, inst:
+            trace = traceback.format_exc()
+            self.log.error("Model: Error raising approve event: %s" % trace)
+            raise
 
     def raiseUndelete(self):
         "Raises onUndelete event."
-        self.onUndelete()
-        message = "Undeleted %s: '%s'" % (
+        message = "Model: Undeleted %s: '%s'" % (
             self.__class__.__name__,
             self.getRegisterKeyValue()
         )
         self.log.info(message)
+        try:
+            self.onUndelete()
+        except Exception, inst:
+            trace = traceback.format_exc()
+            self.log.error("Model: Error raising undelete event: %s" % trace)
+            raise
 
     def raisePurge(self):
         "Raises onPurge event."
-        self.onPurge()
+        message = "Model: Purged %s: '%s'" % (
+            self.__class__.__name__,
+            self.getRegisterKeyValue()
+        )
+        self.log.info(message)
+        try:
+            self.onPurge()
+        except Exception, inst:
+            trace = traceback.format_exc()
+            self.log.error("Model: Error raising purge event: %s" % trace)
+        # Don't re-raise event, because it trips up undoing create.
+
 
     def onCreate(self):
         "Abstract handler for Create object event."
@@ -854,7 +919,7 @@ class DomainObject(DomainBase):
             kwds['startsWithAttributeName'] = self.startsWithAttributeName
         if moddebug and debug:
             className = self.registerClass.__name__
-            message = "Creating '%s' register with kwds: %s" % (className, kwds)
+            message = "Model: Creating '%s' register with kwds: %s" % (className, kwds)
             self.log.debug(message)
         register = self.registerClass(**kwds)
         return register
@@ -878,9 +943,10 @@ class DomainObject(DomainBase):
             self.getRegisterKeyValue(),
         )
     
-    # todo: rename to getLabel
+    def getLabelRepr(self):
+        return self.getLabelValue().encode('utf-8')
+
     def getLabelValue(self):
-        # default to register key value
         return unicode(self.getRegisterKeyValue())
 
     def getPersonalLabel(self):
@@ -920,5 +986,5 @@ class SimpleObject(DomainObject):
 class SimpleNamedObject(DomainObject):
 
     registerKeyName = 'name'
-    name = String(isIndexed=True)
+    name = String(isIndexed=True, isRequired=True)
 
