@@ -378,7 +378,7 @@ class Password(String):
             return u""
 
     def makeValueFromMultiValueDict(self, multiValueDict):
-        passwordText = multiValueDict[self.name]
+        passwordText = multiValueDict.get(self.name, 'pass')
         # Make a digest of the password...
         if self.dictionary[DB_MIGRATION_IN_PROGRESS]:
             # ...unless data migration is in progress, it's already digested.
@@ -472,14 +472,17 @@ class Boolean(ValueObjectAttr):
         )
 
     def makeValueFromMultiValueDict(self, multiValueDict):
-        boolVal = multiValueDict[self.name]
-        if boolVal.__class__ == False.__class__:
-            attrValue = boolVal
+        if self.name not in multiValueDict:
+            attrValue = False
         else:
-            attrValue = str(boolVal).lower() in self.trueStrings
-        if moddebug and self.debug:
-            msg = "Made %s value: %s" % (self.name, attrValue)
-            self.logger.debug(msg)
+            boolVal = multiValueDict[self.name]
+            if boolVal.__class__ == False.__class__:
+                attrValue = boolVal
+            else:
+                attrValue = str(boolVal).lower() in self.trueStrings
+            if moddebug and self.debug:
+                msg = "Made %s value: %s" % (self.name, attrValue)
+                self.logger.debug(msg)
         return attrValue
 
     def createValueRepr(self, domainObject):
