@@ -122,11 +122,6 @@ class StatefulObject(DomainObject):
         if self.state:
             self.state.purgeObject(self)
 
-    def reprAttrs(self):
-        reprAttrs = super(StatefulObject, self).reprAttrs()
-        reprAttrs += " state='%s'" % self.state.name
-        return reprAttrs
-
 
 class NamedStatefulObject(StatefulObject, SimpleNamedObject):
     pass
@@ -152,6 +147,17 @@ class SimpleDatedObject(SimpleObject):
         # todo: convert to localtime
         return self.lastModified
 
+    # Todo: Rename SystemUpSince to SystemStarted.
+    # Todo: Rename SYSTEM_UP_SINCE to SYSTEM_STARTED.
+    def isSystemUpSinceCreated(self):
+        systemStarted = self.dictionary[self.dictionary.words.SYSTEM_UP_SINCE]
+        return systemStarted > self.dateCreated
+
+    def isSystemUpSinceModified(self):
+        systemStarted = self.dictionary[self.dictionary.words.SYSTEM_UP_SINCE]
+        return systemStarted > self.lastModified
+
+
 class SimpleNamedDatedObject(SimpleNamedObject, SimpleDatedObject):
     pass
 
