@@ -8,10 +8,12 @@ class System(SimpleDatedObject):
     version = String(
         default=SimpleDatedObject.dictionary[SYSTEM_VERSION]
     )
+    mode = String(isRequired=False)
 
     def getLabelValue(self):
-        return "%s %s" % (
+        return "%s %s %s" % (
             self.version,
             self.dateCreated,
+            self.mode,
         )
 
