@@ -12,11 +12,11 @@ from dm.dom.temporal import TemporalCollection, BitemporalCollection, Bitemporal
 
 def suite():
     suites = [
-        unittest.makeSuite(TestTemporalProperty),
-        unittest.makeSuite(TestBitemporalActual),
-        unittest.makeSuite(TestBitemporalProperty),
+#        unittest.makeSuite(TestTemporalProperty),
+#        unittest.makeSuite(TestBitemporalActual),
+#        unittest.makeSuite(TestBitemporalProperty),
         # Example of DomainObject with temporal properties.
-        unittest.makeSuite(TestTemporal),   # TestTemporalPropertiesExample
+#        unittest.makeSuite(TestTemporal),   # TestTemporalPropertiesExample
         unittest.makeSuite(TestTemporalObjectExample),
     ]
     return unittest.TestSuite(suites)
@@ -53,8 +53,8 @@ class TestTemporalObjectExample(TestCase):
 
     def tearDown(self):
         super(TestTemporalObjectExample, self).tearDown()
-        if self.instance != None:
-            self.instance.delete()
+        while '' in self.collection:
+            del(self.collection[''])
         self.timepoint.reset()
 
     def test_title(self):
